.. include:: ../README.rst

All Contents
============

.. toctree::
    :maxdepth: 2
    :caption: Contents:
    :glob:

    usage
    templates
    customizing
    settings
    contributing
    *



